Title: [commits] (bkirsch) [11331] cleaned up a few typos in the documentation
Revision
11331
Author
bkirsch
Date
2006-08-04 15:02:19 -0700 (Fri, 04 Aug 2006)

Log Message

cleaned up a few typos in the documentation

Modified Paths

Diff

Modified: trunk/chandler/projects/EggTranslations-Plugin/egg_translations.py (11330 => 11331)

--- trunk/chandler/projects/EggTranslations-Plugin/egg_translations.py	2006-08-04 21:01:59 UTC (rev 11330)
+++ trunk/chandler/projects/EggTranslations-Plugin/egg_translations.py	2006-08-04 22:02:19 UTC (rev 11331)
@@ -198,7 +198,7 @@
 
          @type encoding: c{str} or c{unicode} 
 
-         @param fallback: Indicates where locale set fallback should
+         @param fallback: Indicates whether locale set fallback should
                           take place. If set to True, the 
                           EggTranslations will search all locales 
                           in the locale set till a resource or 
@@ -904,14 +904,14 @@
 
         If fallback was set to True in the
         c{EggTranslations.initialize} method or the
-        c{EggTranslations.setLocale} method, the 
+        c{EggTranslations.setLocaleSet} method, the 
         c{EggTranslations.getText} method will search all 
         locales in the locale set till a gettext mo 
         translation is found for the txt parameter.
 
         If fallback was set to False in the
         c{EggTranslations.initialize} method
-        or the c{EggTranslations.setLocale} method, the
+        or the c{EggTranslations.setLocaleSet} method, the
         c{EggTranslations.getText} method will only search 
         the current locale, which is the first locale in the
         locale set for a gettext mo translation for 
@@ -1034,10 +1034,11 @@
         """
         Returns True if fallback was set to True in either the 
         c{EggTranslations.initialize} method or the 
-        c{EggTranslations.setLocale} method.
+        c{EggTranslations.setLocaleSet} method.
         
         @return: c{boolean} True if fallback set to True
-                 in initialize or setLocale methods otherwise False.
+                 in initialize or setLocaleSet methods 
+                 otherwise False.
         """
         assert(self._init, True)
         return self._fallback
@@ -1099,7 +1100,7 @@
         @type localeSet: c{str} or c{unicode} or c{List} containing 
                          c{str} or c{unicode} values
 
-         @param fallback: Indicates where locale set fallback should
+         @param fallback: Indicates whether locale set fallback should
                           take place. If set to True, the 
                           EggTranslations will search all locales 
                           in the locale set till a resource or 
@@ -1530,7 +1531,7 @@
                             # location of each .mo file.
                             #
                             # This cache will be used by
                             # setLocale method to 
                             # load the EggTranslations 
                             # and build the fallback order
                             # if fallback set to True
@@ -1530,7 +1531,7 @@
                             #
                             # This cache will be used by
-                            # setLocale method to 
+                            # setLocaleSet method to 
                             # load the EggTranslations 
                             # and build the fallback order




_______________________________________________
Commits mailing list
[email protected]
http://lists.osafoundation.org/mailman/listinfo/commits

Reply via email to